DSAdjust class abstract

Constructors

DSAdjust()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isInitialized → bool
no setter

Static Methods

addAfterInitCallback(void callback()) → dynamic
Add callback to be called after initialization
getAdid() → String?
getATTStatus() → Future<int>
Result described in https://github.com/adjust/flutter_sdk/blob/master/README.md#af-att-framework
init({required String adjustKey, bool? launchDeferredDeeplink, bool? launchLinkMeEnabled, DeferredDeeplinkCallback? deferredDeeplinkCallback}) → Future<void>
Initialize DSAdjust adjustKey - API key of Adjust
registerAttributionCallback(DSAttributionCallback callback) → void
Add handler for Adjust -> attributionCallback
requestATT() → Future<num>
Result described in https://github.com/adjust/flutter_sdk/blob/master/README.md#af-att-framework
sendGlobalCallbackParameter(String key, String value) → void
sendGlobalPartnerParameter(String key, String value) → void
trackAdRevenueNew({required double value, required String currencyCode, required String adRevenueNetwork, required String adRevenueUnit}) → void
Just Adjust trackAdRevenueNew call
trackEvent(DSAdjustEvent event) → void
unregisterAttributionCallback(DSAttributionCallback callback) → void
Remove handler for Adjust -> attributionCallback