DSRemoteConfig class

Inheritance

Constructors

DSRemoteConfig({required Map<String, dynamic> defaults, VoidCallback? onInitialized, VoidCallback? onLoaded})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isFullyInitialized → bool
no setter
isInitialized → bool
no setter
postfix → String
no setter
prefix → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getBool(String key, {bool defVal = false}) → bool
Gets the value for a given key as a bool. Returns defVal if the key does not exist.
getDuration(String key, {Duration defVal = const Duration(seconds: 0)}) → Duration
Gets the value for a given key as a Duration. Returns defVal if the key does not exist.
getInt(String key, {int defVal = 0}) → int
Gets the value for a given key as an int. Returns defVal if the key does not exist.
getString(String key, {String defVal = ''}) → String
Gets the value for a given key as a String. Returns defVal if the key does not exist.
getUserXPercent() → int
Will be removed in future versions. Use uxcam_percent
getUserXSessions() → int
getUXCamMinBuild() → int
getUXCamPercent() → int
getUXCamSessions() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setPostfix(String value) → void
setPrefix(String value) → void
toString() → String
A string representation of this object.
inherited
waitForFullInit({dynamic maxWait = const Duration(seconds: 5)}) → Future<void>
waitForInit({dynamic maxWait = const Duration(seconds: 5)}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

I → DSRemoteConfig
no setter